#
# spec file for package libosmo-sccp
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libosmo-sccp
Version:        1.2.0
Release:        lp152.1.3
%define libversion %(echo "%version" | sed 's/\\./_/g')
Summary:        Osmocom library for the A-bis interface between BTS and BSC
License:        AGPL-3.0-or-later AND GPL-2.0-or-later
Group:          Hardware/Mobile
URL:            https://projects.osmocom.org/projects/libosmo-sccp

#Git-Clone:	git://git.osmocom.org/libosmo-sccp
Source:         %name-%version.tar.xz
Patch1:         0001-build-fixes.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  automake >= 1.6
BuildRequires:  libtool >= 2
BuildRequires:  lksctp-tools-devel
BuildRequires:  pkg-config >= 0.20
BuildRequires:  systemd-rpm-macros
BuildRequires:  xz
BuildRequires:  pkgconfig(libosmo-netif) >= 0.7.0
BuildRequires:  pkgconfig(libosmocore) >= 1.3.0
BuildRequires:  pkgconfig(libosmogsm) >= 1.3.0
BuildRequires:  pkgconfig(libosmovty) >= 1.3.0

%description
SCCP is a network layer protocol that provides extended routing, flow
control, segmentation, connection-orientation, and error correction
facilities in Signaling System 7 telecommunications networks. SCCP is
heavily used in cellular networks such as GSM.

%package -n libosmo-mtp-%libversion
Summary:        Osmocom Message Transfer Part library
License:        GPL-2.0-or-later
Group:          System/Libraries

%description -n libosmo-mtp-%libversion
The Message Transfer Part (MTP) is part of the Signaling System 7
(SS7) used for communication in Public Switched Telephone Networks.
MTP is responsible for reliable, unduplicated and in-sequence
transport of SS7 messages between communication partners.

%package -n libosmo-mtp-devel
Summary:        Development files for the Osmocom MTP library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libosmo-mtp-%libversion = %version

%description -n libosmo-mtp-devel
MTP is part of SS7 used for communication in Public Switched
Telephone Networks.

This subpackage contains the development files for the Osmocom MTP
library.

%package -n libosmo-sccp-%libversion
Summary:        Osmocom Signalling Connection Control Part library
License:        GPL-2.0-or-later
Group:          System/Libraries

%description -n libosmo-sccp-%libversion
The Signalling Connection Control Part (SCCP) is a network layer
protocol that provides extended routing, flow control, segmentation,
connection-orientation, and error correction facilities in Signaling
System 7 telecommunications networks. SCCP relies on the services of
MTP for basic routing and error detection.

%package -n libosmo-sccp-devel
Summary:        Development files for the Osmocom SCCP library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libosmo-sccp-%libversion = %version
# previously wrongly shipped .so file
Conflicts:      libosmo-sccp-1_0_0

%description -n libosmo-sccp-devel
SCCP is a network layer protocol that provides routing, flow control,
segmentation, connection-orientation, and error correction facilities
in SS7 telecommunications networks.

This subpackage contains the development files for the Osmocom SCCP
library.

%package -n libosmo-sigtran5
Summary:        Osmocom SIGTRAN library
License:        GPL-2.0-or-later
Group:          System/Libraries

%description -n libosmo-sigtran5
Osmocom implementation of (parts of) SIGTRAN.

%package -n libosmo-sigtran-devel
Summary:        Development files for the Osmocom sigtran library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libosmo-sigtran5 = %version

%description -n libosmo-sigtran-devel
Osmocom implementation of (parts of) SIGTRAN.

This subpackage contains the development files for the Osmocom
SIGTRAN library.

%package -n libosmo-xua-%libversion
Summary:        Osmocom Message Transfer Part 2 User Adaptation library
License:        GPL-2.0-or-later
Group:          System/Libraries

%description -n libosmo-xua-%libversion
M2UA (RFC 3331) provides an SCTP (RFC 3873) adaptation layer for the
seamless backhaul of MTP Level 2 user messages and service interface
across an IP network.

%package -n libosmo-xua-devel
Summary:        Development files for the Osmocom M2UA library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libosmo-sigtran-devel = %version
Requires:       libosmo-xua-%libversion = %version

%description -n libosmo-xua-devel
M2UA provides an SCTP adaptation layer for MTP level 2 user messages
and service interface across an IP network.

This subpackage contains the development files for the Osmocom M2UA
library.

%package -n osmo-stp
Summary:        Osmocom SIGTRAN STP (Signaling Transfer Point)
License:        GPL-2.0-or-later
Group:          Productivity/Telephony/Servers

%description -n osmo-stp
This is the Osmocom (Open Source Mobile Communications)
implementation of a Signaling Transfer Point (STP) for SS7/SIGTRAN
telecommunication networks. At this point, it is a minimal
implementation, missing lots of the functionality usually present in
a STP, such as Global Title Routing, Global Title Translation.

%prep
%autosetup -p1

%build
echo "%version" >.tarball-version
autoreconf -fiv
%configure \
        --disable-static \
        --includedir="%_includedir/%name" \
	--docdir="%_defaultdocdir/%name" \
        --with-systemdsystemunitdir=%_unitdir
make %{?_smp_mflags}

%install
%make_install
find "%buildroot/%_libdir" -type f -name "*.la" -delete
install -d "%buildroot/%_unitdir" "%buildroot/%_sbindir"
ln -s service "%buildroot/%_sbindir/rcosmo-stp"

%check
if ! make %{?_smp_mflags} check; then
	find . -name testsuite.log -exec cat "{}" "+"
%ifnarch ppc64 sparc64 s390x
	# still BE problems?
	exit 1
%endif
fi

%post   -n libosmo-mtp-%libversion -p /sbin/ldconfig
%postun -n libosmo-mtp-%libversion -p /sbin/ldconfig
%post   -n libosmo-sccp-%libversion -p /sbin/ldconfig
%postun -n libosmo-sccp-%libversion -p /sbin/ldconfig
%post   -n libosmo-sigtran5 -p /sbin/ldconfig
%postun -n libosmo-sigtran5 -p /sbin/ldconfig
%post   -n libosmo-xua-%libversion -p /sbin/ldconfig
%postun -n libosmo-xua-%libversion -p /sbin/ldconfig

%preun -n osmo-stp
%service_del_preun osmo-stp.service

%postun -n osmo-stp
%service_del_postun osmo-stp.service

%pre -n osmo-stp
%service_add_pre osmo-stp.service

%post -n osmo-stp
%service_add_post osmo-stp.service

%files -n libosmo-mtp-%libversion
%defattr(-,root,root)
%_libdir/libosmo-mtp-%version.so

%files -n libosmo-mtp-devel
%defattr(-,root,root)
%dir %_includedir/%name
%dir %_includedir/%name/osmocom
%_includedir/%name/osmocom/mtp/
%_libdir/libosmo-mtp.so
%_libdir/pkgconfig/libosmo-mtp.pc

%files -n libosmo-sccp-%libversion
%defattr(-,root,root)
%_libdir/libosmo-sccp-%version.so

%files -n libosmo-sccp-devel
%defattr(-,root,root)
%dir %_includedir/%name
%dir %_includedir/%name/osmocom
%_includedir/%name/osmocom/sccp/
%_libdir/libosmo-sccp.so
%_libdir/pkgconfig/libosmo-sccp.pc

%files -n libosmo-sigtran5
%defattr(-,root,root)
%_libdir/libosmo-sigtran.so.5*

%files -n libosmo-sigtran-devel
%defattr(-,root,root)
%dir %_includedir/%name
%dir %_includedir/%name/osmocom
%_includedir/%name/osmocom/sigtran/
%_libdir/libosmo-sigtran.so
%_libdir/pkgconfig/libosmo-sigtran.pc

%files -n libosmo-xua-%libversion
%defattr(-,root,root)
%_libdir/libosmo-xua-%version.so

%files -n libosmo-xua-devel
%defattr(-,root,root)
%_libdir/libosmo-xua.so
%_libdir/pkgconfig/libosmo-xua.pc

%files -n osmo-stp
%dir %{_sysconfdir}/osmocom
%config %{_sysconfdir}/osmocom/osmo-stp.cfg
%_bindir/osmo-stp
%_sbindir/rcosmo-stp
%_unitdir/osmo-stp.service
%_defaultdocdir/%name/

%changelog
* Tue Jan  7 2020 Jan Engelhardt <jengelh@inai.de>
- Update 0001-build-fixes.patch to build sccp_test with SOURCES,
  not LDADD.
* Sun Jan  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.2.0
  * ASP FSM: Permit DOWN -> DOWN "transition"
  * xua: Implement traffic mode broadcast
  * osmo_ss7: Add osmo_ss7_asp_find()
  * introduce public enum osmo_ss7_asp_role for ASP/SG/IPSP
  * ss7: Implement AS traffic mode loadshare using round robin ASP
    selection
  * ipa: Fix crash when parsing of received IPA SCCP message fails
  * ipa: Don't send non-SCCP data over IPA/SCCPlite
* Thu Aug 15 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.0
  * OsmoSTP: enable statsd support
  * osmo-stp: register VTY commands for talloc context introspection
  * osmo-stp: expose root talloc context to the VTY code
* Mon Jan 28 2019 mardnh@gmx.de
- Update to new upstream release 1.0.0
  * Bugfix release only.
    The full changelog is available via
    http://git.osmocom.org/libosmo-sccp/plain/debian/changelog?h=1.0.0
- Update patch:
  * 0001-build-fixes.patch
* Tue Dec 11 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 0.10.0
  * ipa: Patch DPC/OPC information into SCCP Calling/Called Party
    Address
  * ipa: Automatically create / destroy route on IPA
    connect/disconnect
  * ss7: Re-bind xUA server socket after setting new IP
  * osmo_ss7: Register 5000 as default port for IPA/SCCPlite
  * fix infinite recursion with routing by global title
  * fix use after free in osmo_sccp_simple_server_add_clnt()
  * fix memleak in ipa_rx_msg_sccp
  * fix two memleaks in ipa_rx_msg_sccp()
* Sat Mar 17 2018 mardnh@gmx.de
- Derive libversion from version
- Create subpackage for osmo-stp
- Show testsuite.log when tests are failing
- Cosmetic fixes
- Fix url
* Thu Dec 28 2017 jengelh@inai.de
- Update to new upstream release 0.8.1
  * sccp_scrc: fix Network Indicator in SIO composition
  * osmo_sccp_addr_encode(): Fix truncation of point codes
* Thu Oct 26 2017 dimstar@opensuse.org
- Fix names of shared library packages: the version is 0.7.0.284
  and the soname contains the entire version. As this results in
  package rename, we exceptionally obsolete the old/wrong package
  name in order to facilitate error-free upgrades.
* Mon Oct  2 2017 jengelh@inai.de
- Update to new upstream snapshot 0.7.0.284
  * vty: add 'asp' / 'local-ip' command
  * osmo_ss7_vty: fix 'as' / 'routing-key' command
  * OsmoSTP: Install our default set of signal handlers
  * Fix SCCP client crash on xUA server (STP) disconnect
  * vty: hide SG commands when running as ASP
  * sccp: fix creating of the default route in simple client
  * sccp: derive local address from given sccp instance
* Fri Apr 28 2017 jengelh@inai.de
- Update to new upstream snapshot 0.7.0.208
  * Add new 'osmo_ss7' SS7 core code with M3UA, ASP/AS FSM, ...
  * Add SCCP <-> SUA message transcoding routines
  * Add tests for xUA code + SCCP/SUA transcoding
  * Add new SCCP implementation
  * Add M3UA RKM (routing key management) support, SGW side only
  * SCCP: Add VTY interface for SCCP
* Fri Jan 22 2016 jengelh@inai.de
- Update to new upstream snapshot 0.7.0.11
  * Add missing OSMO_SCCP_SSN_RANAP for RANAP SSN
  * Properly define SCCP_SAP_USER without random magic number
  * Import SUA (SCCP User Adaptation) and SCCP User SAP
* Thu Sep 10 2015 jengelh@inai.de
- Update to new upstream release 0.7.0
  * sccp: Allow to specify the context of the incoming message
  * mtp: Correct the pointcode mask
  * mtp: Add implementation from cellmgr
  * m3ua: Add the definition of the protocol data header
  * xua: Generalize the m2ua_msg and call it xua_msg
  * XUA: Move m2ua headers to sigtran, create xua_types.h
  and m3ua_types.h
  * sccp: Create sccp_create_cr and use it in the connection creation
* Mon Jul 21 2014 jengelh@inai.de
- Initial package (version 0.0.6.3) for build.opensuse.org
